all.Evesm<-function(){
     cat("\n")
     note_for_Evesm_input()
     cat("\n")
     note_for_close_window()
     EveSMMpar<-data.frame(parameter=c("bw (kg)","age (yr)","race","Ery","D (mg)","tau (hr)"),value=c(0))
     EveSMMpar<-edit(EveSMMpar)
##     EveSMMpar<-ycheck(EveSMMpar)
     cat("\n")
     note_for_Evesm_conc_input()
     cat("\n")
     note_for_close_window()
     EveSMpar<-data.frame(ts=c(0),conc=c(0))
     EveSMpar<-edit(EveSMpar)
##     EveSMpar<-mscheck(EveSMpar)
     cat("\n")
     Eve.sm(length(EveSMpar$ts),EveSMpar$conc,EveSMpar$ts,EveSMMpar[6,2],EveSMMpar[5,2],EveSMMpar[1,2],EveSMMpar[2,2],EveSMMpar[3,2],EveSMMpar[4,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Evesm_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Evecpr(6.07,EveSMMpar[5,2],EveSMMpar[6,2],EveSMMpar[6,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mcg/L)")
     show(coutput)    
     cat("\n") 
     Eve.more()
}